@@ -2,7 +2,10 @@
 from logging.handlers import RotatingFileHandler
 import logging
 import datetime as dt
+import re
+import json
 import tempfile
+import os
 from pkg_resources import resource_filename
 
 # Misc
@@ -66,7 +69,7 @@ WIKI_URL = "https://github.com/labsquare/cutevariant/wiki"
 
 # Logging
 LOGGER_NAME = "cutevariant"
-LOG_LEVEL = "INFO"
+LOG_LEVEL = "DEBUG"
 LOG_LEVELS = {
     "debug": logging.DEBUG,
     "info": logging.INFO,
@@ -146,3 +149,59 @@ def get_uncompressed_size(filepath):
     with open(filepath, "rb") as file_obj:
         file_obj.seek(-4, 2)
         return int.from_bytes(file_obj.read(4), byteorder="little")
+
+
+def bytes_to_readable(size) -> str:
+    """return human readable size from bytes
+    
+    Args:
+        size (int): size in bytes
+    
+    Returns:
+        str: readable size
+    """
+    out = ""
+    for count in ["Bytes", "KB", "MB", "GB"]:
+        if size > -1024.0 and size < 1024.0:
+            return "%3.1f%s" % (size, count)
+        size /= 1024.0
+    return "%3.1f%s" % (size, "TB")
+
+
+def snake_to_camel(name: str) -> str:
+    """Convert snake_case name to CamelCase name
+
+    Args:
+        name (str): a snake string like : query_view
+
+    Returns:
+        str: a camel string like: QueryView
+    """
+    return "".join([i.capitalize() for i in name.split("_")])
+
+
+def camel_to_snake(name: str) -> str:
+    """Convert CamelCase to snake_case name
+
+    Args:
+        name (str): a snake string like : QueryView
+
+    Returns:
+        str: a camel string like: query_view
+    """
+    name = re.sub("(.)([A-Z][a-z]+)", r"\1_\2", name)
+    return re.sub("([a-z0-9])([A-Z])", r"\1_\2", name).lower()
+
+
+def is_json_file(filename):
+
+    if not os.path.exists(filename):
+        return False
+
+    with open(filename) as file:
+        try:
+            json.load(file)
+        except Exception as e:
+            return False
+        finally:
+            return True
