@@ -1,6 +1,7 @@
 from abc import ABC, abstractmethod
 import io
 import gzip
+import math
 from collections import Counter
 import cutevariant.commons as cm
 
@@ -24,6 +25,9 @@ class AbstractReader(ABC):
             It's a fallback if number_lines can't be computed.
         samples: List of samples in the file (default: empty)
 
+        ignored_fields: Skip fields in importations. 
+            A list of fields to skip [{field_name:"AF", "category":"variant"}]
+
     Example:
         >>> with open(filename,"r") as file:
         ...    reader = Reader(file)
@@ -39,6 +43,8 @@ class AbstractReader(ABC):
         self.file_size = self.get_total_file_size()
         self.compute_number_lines()
 
+        self.ignored_fields = set()
+
     @classmethod
     @abstractmethod
     def get_variants(cls):
@@ -241,12 +247,26 @@ class AbstractReader(ABC):
         duplicates = set()
         for field in self.get_fields():
             # Create unique identifiant by categories
-            unique_key = field["category"]+"."+field["name"]
-            if unique_key not in duplicates:
+            unique_key = field["category"] + "." + field["name"]
+            is_unique = unique_key not in duplicates
+            is_ignored = (field["name"], field["category"]) in self.ignored_fields
+            if is_unique and not is_ignored:
                 yield field
 
             duplicates.add(unique_key)
 
+    def add_ignored_field(self, field_name: str, field_category: str):
+        """Add new field to the ignored_fields list. 
+        ignored fields will not returned by get_extra_fields and then are not imporpted 
+        into the database 
+        
+        Args:
+            field_name (str): a field name 
+            field_category (str): the category field name (variant,annotation,sample)
+        """
+
+        self.ignored_fields.add((field_name, field_category))
+
     def get_extra_variants(self, **kwargs):
         """Yield variants with extra information computed.
 
@@ -298,8 +318,9 @@ class AbstractReader(ABC):
             # Samples can't be both in cases and controls
             case_samples = kwargs["case"]
             control_samples = kwargs["control"]
-            assert not set(case_samples) & set(control_samples), \
-                "Found sample both in cases and controls!"
+            assert not set(case_samples) & set(
+                control_samples
+            ), "Found sample both in cases and controls!"
             case_and_control_samples_found = True
 
         for variant in self.get_variants():
@@ -351,7 +372,23 @@ class AbstractReader(ABC):
                 variant["control_count_het"] = control_counter[1]
                 variant["control_count_ref"] = control_counter[0]
 
-            yield variant
+            # Remove ignore variants
+            for name, category in self.ignored_fields:
+                if category == "variants":
+                    if name in variant:
+                        del variant[name]
+                # remove from category
+                if category == "annotations":
+                    for ann in variant["annotations"]:
+                        if name in ann:
+                            del ann[name]
+
+                if category == "samples":
+                    for sample in variant["samples"]:
+                        if name in sample:
+                            del sample[name]
+
+            yield nullify(variant)
 
     def get_extra_fields_by_category(self, category: str):
         """Syntaxic suggar to get fields according their category
@@ -526,3 +563,38 @@ def sanitize_field_name(field: str):
     # TODO
     LOGGER.warning("NOT implemented function!!")
     return field
+
+
+def nullify(variant: dict) -> dict:
+    """ Convert empty fields value  to NONE 
+    This is used have NULL value inside the SQLITE inside an empty string
+
+    """
+
+    def convert_to_none(value):
+        """ convert value to None according type """
+        EMPTY_STRING = ["", "."]
+        if isinstance(value, str):
+            if value in EMPTY_STRING:
+                return None
+
+        if isinstance(value, float) or isinstance(value, int):
+            if math.isnan(value):
+                return None
+
+        return value
+
+    for key in variant.keys():
+        variant[key] = convert_to_none(variant[key])
+
+        if key == "annotations":
+            for ann in variant["annotations"]:
+                for ann_key in ann.keys():
+                    ann[ann_key] = convert_to_none(ann[ann_key])
+
+        if key == "samples":
+            for sample in variant["samples"]:
+                for sample_key in sample.keys():
+                    sample[sample_key] = convert_to_none(sample[sample_key])
+
+    return variant
