@@ -9,12 +9,48 @@ from functools import lru_cache
 from typing import Any, Iterable
 
 # Qt imports
-from PySide2.QtWidgets import *
-from PySide2.QtCore import *
-from PySide2.QtGui import *
+from PySide2.QtWidgets import (
+    QWidget,
+    QTreeView,
+    QFrame,
+    QToolButton,
+    QPushButton,
+    QCompleter,
+    QDialog,
+    QFileDialog,
+    QApplication,
+    QStyledItemDelegate,
+    QToolBar,
+    QAbstractItemView,
+    QHeaderView,
+    QComboBox,
+    QSizePolicy,
+    QMessageBox,
+    QHBoxLayout,
+    QVBoxLayout,
+    QMenu,
+    QStyle,
+)
+from PySide2.QtCore import (
+    Qt,
+    QObject,
+    Signal,
+    Slot,
+    QDir,
+    QAbstractItemModel,
+    QModelIndex,
+    QMimeData,
+    QEvent,
+    QStandardPaths,
+    QSize,
+    QFileInfo,
+    QSettings,
+    QRect,
+)
+from PySide2.QtGui import QPainter, QPalette, QFont, QPen, QBrush
 
 # Custom imports
-from cutevariant.gui import style, plugin
+from cutevariant.gui import style, plugin, FIcon
 from cutevariant.core import sql, get_sql_connection
 from cutevariant.core.vql import parse_one_vql
 from cutevariant.core.querybuilder import (
@@ -331,6 +367,8 @@ class OperatorField(BaseField):
         "~": "regex",
         "IN": "in",
         "NOT IN": "not in",
+        "IS": "is",
+        "IS NOT": "is not",
     }
 
     def __init__(self, parent=None):
@@ -672,6 +710,7 @@ class FilterModel(QAbstractItemModel):
         super().__init__(parent)
         self.root_item = FilterItem("AND")
         self.conn = conn
+        self.clear()
 
     @property
     def filters(self):
@@ -854,6 +893,15 @@ class FilterModel(QAbstractItemModel):
             if orientation == Qt.Horizontal:
                 return self._HEADERS[section]
 
+    def is_last(self, index: QModelIndex()) -> bool:
+        """Return True if index is the last in the row
+        This is used by draw_branch
+        """
+        if index == QModelIndex():
+            return False
+
+        return index.row() == index.model().rowCount(index.parent()) - 1
+
     def index(self, row, column, parent=QModelIndex()) -> QModelIndex:
         """Overrided Qt methods: create index according row, column and parent
 
@@ -883,6 +931,7 @@ class FilterModel(QAbstractItemModel):
             return QModelIndex()
 
         child_item = index.internalPointer()
+
         parent_item = child_item.parent
 
         if parent_item == self.root_item:
@@ -892,7 +941,12 @@ class FilterModel(QAbstractItemModel):
 
     def clear(self):
         """Clear Model"""
+        self.beginResetModel()
         self.root_item.children.clear()
+        # Load first default item
+        self.root_item.append(FilterItem("AND"))
+
+        self.endResetModel()
 
     def load(self, data: dict):
         """load model from dict
@@ -910,8 +964,8 @@ class FilterModel(QAbstractItemModel):
             data (TYPE): Description
         """
         self.beginResetModel()
-        self.clear()
         if data:
+            self.root_item.children.clear()
             self.root_item.append(self.to_item(data))
         self.endResetModel()
 
@@ -1187,6 +1241,16 @@ class FilterModel(QAbstractItemModel):
             cindex = self.index(row, 0, index)
             self.set_recursive_check_state(cindex, checked)
 
+    def to_json(self, filename: str):
+
+        with open(filename, "w") as file:
+            json.dump(self.to_dict(), file)
+
+    def from_json(self, filename: str):
+        with open(filename, "r") as file:
+            data = json.load(file)
+            self.filters = data
+
 
 class FilterDelegate(QStyledItemDelegate):
     """FilterDelegate is used to create widget editor for the model inside the view.
@@ -1226,13 +1290,17 @@ class FilterDelegate(QStyledItemDelegate):
     def __init__(self, parent=None):
         super().__init__(parent)
 
-        self.add_icon = FIcon(0xF0419)
-        self.rem_icon = FIcon(0xF0156)
+        self.add_icon = FIcon(0xF0704)
+        self.group_icon = FIcon(0xF0704)
+        self.rem_icon = FIcon(0xF0156, "red")
 
         self.eye_on = FIcon(0xF06D0)
         self.eye_off = FIcon(0xF06D1)
 
-        self.icon_size = QSize(16, 16)
+        self.icon_size = QSize(20, 20)
+
+        self.indentation = 12
+        self.branch_width = 8
 
     def createEditor(self, parent, option, index: QModelIndex) -> QWidget:
         """Overrided from Qt. Create an editor for the selected column.
@@ -1340,8 +1408,10 @@ class FilterDelegate(QStyledItemDelegate):
         if not index.isValid():
             return False
 
+        # Skip action with First LogicItem root item
+
         if event.type() == QEvent.MouseButtonPress:
-            # print("mouse pressed on", index.column(), event.button())
+
             item = model.item(index)
 
             if index.column() == self.COLUMN_CHECKBOX and self._check_rect(
@@ -1355,7 +1425,10 @@ class FilterDelegate(QStyledItemDelegate):
                 option.rect
             ).contains(event.pos()):
                 # Remove item
-                model.remove_item(index)
+
+                # Do not remove first elements
+                if index.parent() != QModelIndex():
+                    model.remove_item(index)
                 return True
 
         # Default implementation of base method
@@ -1413,7 +1486,7 @@ class FilterDelegate(QStyledItemDelegate):
             return QSize(20, 30)
 
         if index.column() == self.COLUMN_FIELD:
-            margin = self._compute_margin(index)
+            margin = self.indentation * self._compute_level(index) + self.indentation
             size.setWidth(size.width() + margin + 10)
 
         return size
@@ -1427,13 +1500,49 @@ class FilterDelegate(QStyledItemDelegate):
 
         return level
 
-    def _compute_margin(self, index: QModelIndex):
-        return self._compute_level(index) * 10 + 5
+    def _draw_branch(self, painter, option, index):
 
-    def paint(
-        self, painter: QPainter, option: QStyleOptionViewItem, index: QModelIndex
-    ):
+        if index.parent() == QModelIndex():
+            return
 
+        item = index.model().item(index)
+        parent = index.model().item(index.parent())
+        level = self._compute_level(index)
+        color = option.palette.color(QPalette.WindowText)
+
+        pen = QPen(color, 1, Qt.DotLine)
+        painter.setPen(pen)
+        xstart = option.rect.x() + self.indentation * (level - 1)
+        xend = xstart + self.branch_width
+
+        #  draw horizontal
+        painter.drawLine(
+            xstart + 2, option.rect.center().y(), xend, option.rect.center().y()
+        )
+
+        #  Draw Vertical
+        ## If last
+        if index.model().is_last(index):
+            yend = option.rect.center().y()
+            painter.drawLine(xstart, option.rect.top(), xstart, yend)
+
+        # If middle
+        else:
+            yend = option.rect.bottom()
+            painter.drawLine(xstart, option.rect.top(), xstart, yend)
+
+        if level > 1:
+            x = xstart
+            current = index
+            while current != QModelIndex():
+                if not index.model().is_last(current):
+                    painter.drawLine(x, option.rect.top(), x, option.rect.bottom())
+                current = current.parent()
+                x -= self.indentation
+
+    def paint(self, painter, option, index):
+
+        # ======== Draw background
         item = index.model().item(index)
         is_selected = False
 
@@ -1441,6 +1550,7 @@ class FilterDelegate(QStyledItemDelegate):
             bg = (
                 QPalette.Normal
                 if option.state & QStyle.State_Active
+                or option.state & QStyle.State_Selected
                 else QPalette.Inactive
             )
         else:
@@ -1450,21 +1560,10 @@ class FilterDelegate(QStyledItemDelegate):
             is_selected = True
             painter.fillRect(option.rect, option.palette.color(bg, QPalette.Highlight))
 
-        # Indentation level
-        margin = self._compute_margin(index)
+        margin = self.indentation * (self._compute_level(index))
 
-        rect = option.rect
-        # Add margin for column 1 and 0
-        if index.column() <= 1:
-            rect.setLeft(rect.x() + margin)
-
-        # ========== Check box ====================
+        #  ========= Draw Checkbox
         if index.column() == self.COLUMN_CHECKBOX:
-            # cbOpt = QStyleOptionButton()
-            # cbOpt.rect = self._check_rect(rect)
-            # cbOpt.setLeft(cbOpt.rect.x() + margin)
-            # cbOpt.state |= QStyle.State_On if item.checked else QStyle.State_Off
-            # QApplication.instance().style().drawControl(QStyle.CE_CheckBox, cbOpt, painter)
 
             check_icon = self.eye_on if item.checked else self.eye_off
             rect = QRect(0, 0, self.icon_size.width(), self.icon_size.height())
@@ -1474,6 +1573,25 @@ class FilterDelegate(QStyledItemDelegate):
 
         if index.column() > self.COLUMN_CHECKBOX:
 
+            if index.column() == 1:
+                self._draw_branch(painter, option, index)
+            # pen = QPen(QColor("white"), 1, Qt.DotLine)
+            # painter.setPen(pen)
+            # # painter.drawRect(option.rect)
+            # painter.drawLine(
+            #     option.rect.left(),
+            #     option.rect.center().y(),
+            #     margin - 2,
+            #     option.rect.center().y(),
+            # )
+
+            # painter.drawLine(
+            #     option.rect.left(),
+            #     option.rect.top(),
+            #     option.rect.left(),
+            #     option.rect.bottom(),
+            # )
+
             font = QFont()
             align = Qt.AlignVCenter
             color = option.palette.color(
@@ -1481,9 +1599,27 @@ class FilterDelegate(QStyledItemDelegate):
                 QPalette.HighlightedText if is_selected else QPalette.WindowText,
             )
 
-            if item.type == FilterItem.LOGIC_TYPE:
+            if (
+                item.type == FilterItem.LOGIC_TYPE
+                and index.column() == self.COLUMN_FIELD
+            ):
                 font.setBold(True)
-
+                # metric = QFontMetrics(font)
+                # print(self._compute_level(index))
+                # text_width = metric.boundingRect(index.data()).width()
+                # #  Draw Add buttion
+                # rect = QRect(0, 0, self.icon_size.width(), self.icon_size.height())
+                # rect.moveCenter(
+                #     QPoint(
+                #         option.rect.x() + margin + text_width + 20,
+                #         option.rect.center().y(),
+                #     )
+                # )
+                # painter.drawPixmap(
+                #     rect.right() - self.icon_size.width(),
+                #     rect.y(),
+                #     self.add_icon.pixmap(self.icon_size),
+                # )
             if index.column() == self.COLUMN_FIELD:
                 align |= Qt.AlignLeft
 
@@ -1495,9 +1631,16 @@ class FilterDelegate(QStyledItemDelegate):
 
             painter.setFont(font)
             painter.setPen(color)
-            painter.drawText(rect, align, index.data(Qt.DisplayRole))
+            # Indentation level
 
-            if index.column() == self.COLUMN_REMOVE:
+            text_rect = option.rect
+            if index.column() == 1:
+                xstart = option.rect.x() + margin
+                text_rect.setX(xstart)
+
+            painter.drawText(text_rect, align, index.data(Qt.DisplayRole))
+
+            if index.column() == self.COLUMN_REMOVE and index.parent() != QModelIndex():
                 rect = QRect(0, 0, self.icon_size.width(), self.icon_size.height())
                 rect.moveCenter(option.rect.center())
                 painter.drawPixmap(
@@ -1535,8 +1678,9 @@ class FilterDelegate(QStyledItemDelegate):
         """
 
         if index.column() == 1:
-            margin = self._compute_margin(index)
-            option.rect.setLeft(option.rect.x() + margin)
+            option.rect.setLeft(
+                option.rect.x() + self.indentation * (self._compute_level(index) - 1)
+            )
             editor.setGeometry(option.rect)
             return
 
@@ -1654,6 +1798,7 @@ class FiltersEditorWidget(plugin.PluginWidget):
         self.settings = QSettings()
         self.view = QTreeView()
         # conn is always None here but initialized in on_open_project()
+
         self.model = FilterModel(conn)
         self.delegate = FilterDelegate()
         self.toolbar = QToolBar()
@@ -1665,6 +1810,8 @@ class FiltersEditorWidget(plugin.PluginWidget):
         self.view.setDragEnabled(True)
         self.view.header().setStretchLastSection(False)
         self.view.setAcceptDrops(True)
+        self.view.setExpandsOnDoubleClick(False)
+
         self.view.setDragDropMode(QAbstractItemView.InternalMove)
         self.view.setAlternatingRowColors(True)
         self.view.setIndentation(0)
@@ -1679,52 +1826,68 @@ class FiltersEditorWidget(plugin.PluginWidget):
         self.view.header().hide()
 
         self.combo = QComboBox()
+        self.combo.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
         self.combo.addItem(self.tr("Current not saved filter..."))
-        self.combo.currentTextChanged.connect(self.on_combo_changed)
-        self.load_predefined_filters()
 
-        self.save_button = QToolButton()
-        self.save_button.setIcon(FIcon(0xF0193))
-        self.save_button.setToolTip(self.tr("Save the current filter"))
-        self.save_button.clicked.connect(self.on_save_filters)
-        self.del_button = QToolButton()
-        self.del_button.setDefaultAction(
-            QAction(FIcon(0xF0A7A), self.tr("Delete the filter"))
-        )
-        self.del_button.clicked.connect(self.on_delete_item)
+        # self.save_button = QToolButton()
+        # self.save_button.setIcon(FIcon(0xF0193))
+        # self.save_button.setToolTip(self.tr("Save the current filter"))
+        # self.save_button.clicked.connect(self.on_save_filters)
+        # self.del_button = QToolButton()
+        # self.del_button.setDefaultAction(
+        #     QAction(FIcon(0xF0A7A), self.tr("Delete the filter"))
+        # )
+        # self.del_button.clicked.connect(self.on_delete_item)
         # Adjust heights
         # self.combo.setMinimumHeight(30)
         # self.save_button.setMinimumHeight(30)
         # self.del_button.setMinimumHeight(30)
 
+        self.add_filter_button = QPushButton("Add Filter")
+        self.add_filter_button.setFlat(True)
+        self.add_group_button = QPushButton("Add Group")
+        self.add_group_button.setFlat(True)
+        self.add_filter_button.clicked.connect(self.on_add_condition)
+        self.add_group_button.clicked.connect(self.on_add_logic)
+
+        blayout = QHBoxLayout()
+        blayout.addWidget(self.add_filter_button)
+        blayout.addWidget(self.add_group_button)
+
         self.apply_button = QPushButton(FIcon(0xF0233), self.tr("Apply filter"))
         self.apply_button.clicked.connect(self.on_filters_changed)
-        hlayout = QHBoxLayout()
-        hlayout.addWidget(self.combo)
-        hlayout.addWidget(self.save_button)
-        hlayout.addWidget(self.del_button)
 
         # setup Menu
-        self.add_button = self.toolbar.addAction(
-            FIcon(0xF0EF0), self.tr("Add Condition"), self.on_add_condition
-        )
-        spacer = QWidget()
-        spacer.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
-        self.toolbar.addWidget(spacer)
-
         self.toolbar.addWidget(self.combo)
-        self.toolbar.addWidget(self.save_button)
-        self.toolbar.addWidget(self.del_button)
+
+        self.file_menu = QMenu()
+        self.file_menu.addAction(FIcon(0xF0818), "Save ", self.on_save)
+        self.file_menu.addAction(FIcon(0xF0CFC), "Save as ...", self.on_save_as)
+        self.file_menu.addAction(FIcon(0xF0156), "Clear", self.model.clear)
+        self.file_menu.addAction(FIcon(0xF0A7A, "red"), "Delete ...", self.on_delete)
+        self.file_menu.addSeparator()
+        self.file_menu.addAction(
+            FIcon(0xF0DCE), "set default directory ...", self.on_set_directory
+        )
+
+        self.menu_button = QToolButton()
+        self.menu_button.setIcon(FIcon(0xF035C))
+        self.menu_button.setMenu(self.file_menu)
+        self.menu_button.setPopupMode(QToolButton.InstantPopup)
+        self.toolbar.addWidget(self.menu_button)
 
         layout = QVBoxLayout()
 
         layout.addWidget(self.toolbar)
         layout.addWidget(self.view)
+        layout.addLayout(blayout)
         layout.addWidget(self.apply_button)
         layout.setContentsMargins(0, 0, 0, 0)
         layout.setSpacing(1)
         self.setLayout(layout)
 
+        self.combo.currentIndexChanged.connect(self.on_combo_changed)
+
         # self.model.filtersChanged.connect(self.on_filters_changed)
 
     @property
@@ -1742,43 +1905,44 @@ class FiltersEditorWidget(plugin.PluginWidget):
 
         # Clear lru_cache
         prepare_fields.cache_clear()
-
+        self.load_combo()
+        self.on_combo_changed(0)
         self.on_refresh()
 
-    def load_predefined_filters(self):
-        """Load user and software defined filters)
+    # def load_predefined_filters(self):
+    #     """Load user and software defined filters)
 
-        - Software defined filters are loaded from "filter.json" embedded
-            in the current plugin folder.
-        - User defined filters are loaded from app settings, under the key
-            `plugins/filters_editor/filters`.
-        """
-        json_file_path = os.path.join(os.path.dirname(__file__), "filters.json")
+    #     - Software defined filters are loaded from "filter.json" embedded
+    #         in the current plugin folder.
+    #     - User defined filters are loaded from app settings, under the key
+    #         `plugins/filters_editor/filters`.
+    #     """
+    #     json_file_path = os.path.join(os.path.dirname(__file__), "filters.json")
 
-        filters = dict()
-        # Open from embedded JSON and load software filters
-        if os.path.isfile(json_file_path):
-            with open(json_file_path, encoding="utf8") as f_d:
-                try:
-                    filters = json.loads(f_d.read())
-                except json.decoder.JSONDecodeError as e:
-                    LOGGER.exception(e)
-            LOGGER.debug("Loaded predefined filters:", filters)
+    #     filters = dict()
+    #     # Open from embedded JSON and load software filters
+    #     if os.path.isfile(json_file_path):
+    #         with open(json_file_path, encoding="utf8") as f_d:
+    #             try:
+    #                 filters = json.loads(f_d.read())
+    #             except json.decoder.JSONDecodeError as e:
+    #                 LOGGER.exception(e)
+    #         LOGGER.debug("Loaded predefined filters:", filters)
 
-        # Overwrite software filters with user defined filters
-        self.settings.beginGroup("plugins/filters_editor/filters")
-        filters.update(
-            {
-                filter_name: self.settings.value(filter_name)
-                for filter_name in self.settings.childKeys()
-            }
-        )
-        self.settings.endGroup()
+    #     # Overwrite software filters with user defined filters
+    #     self.settings.beginGroup("plugins/filters_editor/filters")
+    #     filters.update(
+    #         {
+    #             filter_name: self.settings.value(filter_name)
+    #             for filter_name in self.settings.childKeys()
+    #         }
+    #     )
+    #     self.settings.endGroup()
 
-        # Load in combobox
-        for filter_name, filter_query in filters.items():
-            vql_obj = parse_one_vql(filter_query)
-            self.combo.addItem(filter_name, vql_obj["filters"])
+    #     # Load in combobox
+    #     for filter_name, filter_query in filters.items():
+    #         vql_obj = parse_one_vql(filter_query)
+    #         self.combo.addItem(filter_name, vql_obj["filters"])
 
     def on_refresh(self):
         """Overrided"""
@@ -1787,37 +1951,59 @@ class FiltersEditorWidget(plugin.PluginWidget):
             return
 
         # Filters changed: Update UserRole of default filter and select it
-        self.combo.setItemData(0, self.mainwindow.state.filters)
-        self.combo.setCurrentIndex(0)
 
         self.refresh_buttons()
         self._update_view_geometry()
 
+    @property
+    def filter_path(self):
+        """ Return filter path from settings """
+        settings = QSettings()
+        settings.beginGroup(self.plugin_name)
+        return settings.value(
+            "filter_path", QStandardPaths.writableLocation(QStandardPaths.DataLocation)
+        )
+
+    @filter_path.setter
+    def filter_path(self, value: str):
+        settings = QSettings()
+        settings.beginGroup(self.plugin_name)
+        return settings.setValue("filter_path", value)
+
     def refresh_buttons(self):
         """Actualize the enable states of Add/Del buttons"""
+
         if self.filters:
             # Data
-            # Deletion/clear is always possible
-            self.del_button.setEnabled(True)
 
             # Add button: Is an item selected ?
             index = self.view.currentIndex()
             if index.isValid() and self.model.item(index).type == FilterItem.LOGIC_TYPE:
-                self.add_button.setEnabled(True)
+                self.add_filter_button.setEnabled(True)
+                self.add_group_button.setEnabled(True)
             else:
                 # item is CONDITION_TYPE or there is no item selected (because of deletion)
-                self.add_button.setEnabled(False)
-        else:
-            # Empty
-            self.add_button.setEnabled(True)
+                self.add_filter_button.setEnabled(False)
+                self.add_group_button.setEnabled(False)
 
-            current_index = self.combo.currentIndex()
-            if current_index == 0:
-                # Not saved filter => useless to delete it
-                self.del_button.setEnabled(False)
-            else:
-                # Saved filter => allow its deletion
-                self.del_button.setEnabled(True)
+    def load_combo(self):
+
+        self.combo.clear()
+
+        folder = QDir(self.filter_path)
+        for index, file_info in enumerate(
+            folder.entryInfoList(["*.filter.json"], QDir.Files)
+        ):
+            self.combo.addItem(
+                FIcon(0xF0E29),
+                str(file_info.baseName()),
+                str(file_info.absoluteFilePath()),
+            )
+
+            #  Security
+            if index > 1000:
+                LOGGER.warning("Too many file filters. Some filters are not imported")
+                break
 
     def on_filters_changed(self):
         """Triggered when filters changed FROM THIS plugin
@@ -1829,18 +2015,6 @@ class FiltersEditorWidget(plugin.PluginWidget):
             self.mainwindow.state.filters = self.filters
             self.mainwindow.refresh_plugins(sender=self)
 
-        # Filters changed:
-        # - item in combobox has been changed
-        # - filters in current filter has been changed
-        # Filters are read only, so we must go to the unsaved one.
-        current_index = self.combo.currentIndex()
-        if current_index != 0 and self.combo.currentData() != self.filters:
-            # Update UserRole of default no saved filter and select it
-            self.combo.blockSignals(True)
-            self.combo.setItemData(0, self.filters)
-            self.combo.setCurrentIndex(0)
-            self.combo.blockSignals(False)
-
         self.refresh_buttons()
 
     def on_add_logic(self):
@@ -1852,50 +2026,84 @@ class FiltersEditorWidget(plugin.PluginWidget):
 
             self._update_view_geometry()
 
-    def on_save_filters(self):
-        """Called when Save button is clicked
+    def on_save_as(self):
 
-        Save the current filter into a new independent filter:
-            - In the combobox
-            - In user defined filters (in app settings, under the key
-                `plugins/filters_editor/filters`);
-                Note that such filters are removed when a user clicks on
-                del_button.
-        """
-        filter_name, _ = QInputDialog.getText(
-            self, self.tr("Type a name for the filter"), self.tr("Filter Name:")
+        dialog = QFileDialog()
+        dialog.setDirectory(
+            QStandardPaths.writableLocation(QStandardPaths.DataLocation)
         )
-        if not filter_name:
+        dialog.setDefaultSuffix("filter.json")
+        dialog.setNameFilter("*.filter.json")
+        dialog.setAcceptMode(QFileDialog.AcceptSave)
+
+        if dialog.exec_():
+            if dialog.selectedFiles():
+                filename = dialog.selectedFiles()[0]
+                self.model.to_json(filename)
+                self.load_combo()
+                file_info = QFileInfo(filename)
+                self.combo.setCurrentText(file_info.baseName())
+
+    def on_save(self):
+
+        if self.combo.currentData() is None:
+            self.on_save_as()
             return
 
-        # Save current filters in UserRole of a new ComboBox item
-        self.combo.addItem(filter_name, self.filters)
-        self.combo.setCurrentIndex(self.combo.findText(filter_name))
+        msgBox = QMessageBox()
+        msgBox.setText("The filter has been modified.")
+        msgBox.setInformativeText("Do you want to override the file ?")
+        msgBox.setStandardButtons(QMessageBox.Save | QMessageBox.Discard)
+        msgBox.setDefaultButton(QMessageBox.Save)
 
-        # Convert current query into VQL query and save it in app settings
-        vql_query = build_vql_query(
-            self.mainwindow.state.fields,
-            self.mainwindow.state.source,
-            self.mainwindow.state.filters,
-            self.mainwindow.state.group_by,
-            self.mainwindow.state.having,
-        )
+        if msgBox.exec_():
+            filename = self.combo.currentData()
+            if os.path.exists(filename):
+                self.model.to_json(filename)
 
-        self.settings.beginGroup("plugins/filters_editor/filters")
-        self.settings.setValue(filter_name, vql_query)
-        self.settings.endGroup()
+    def on_set_directory(self):
 
-    def on_combo_changed(self):
-        """Called when a new item is selected in the ComboBox (programatically or not)"""
-        filters = self.combo.currentData()
-        if filters:
-            self.filters = filters
-        else:
-            # Empty filter
+        dialog = QFileDialog()
+        dialog.setDirectory(self.filter_path)
+        dialog.setAcceptMode(QFileDialog.AcceptOpen)
+        dialog.setFileMode(QFileDialog.DirectoryOnly)
+        if dialog.exec_():
+            if dialog.selectedFiles():
+                filename = dialog.selectedFiles()[0]
+                if filename:
+                    self.filter_path = filename
+
+        self.load_combo()
+
+    def on_delete(self):
+        filename = self.combo.currentData()
+        if filename == None:
             self.model.clear()
+            return
 
-        self._update_view_geometry()
-        self.on_filters_changed()
+        msgBox = QMessageBox()
+        msgBox.setText(f"Remove {filename}")
+        msgBox.setInformativeText("Do you want to remove this file ?")
+        msgBox.setStandardButtons(QMessageBox.Save | QMessageBox.Discard)
+        msgBox.setDefaultButton(QMessageBox.Save)
+
+        if msgBox.exec():
+            if os.path.exists(filename):
+                os.remove(filename)
+                self.model.clear()
+                self.load_combo()
+
+    def on_combo_changed(self, index):
+        """Called when a new item is selected in the ComboBox (programatically or not)"""
+        filename = self.combo.itemData(index)
+        print(filename)
+
+        if filename:
+            self.combo.setToolTip(filename)
+            self.model.from_json(filename)
+            self.on_filters_changed()
+            self._update_view_geometry()
+        # self.on_filters_changed()
 
     def _update_view_geometry(self):
         """Set column Spanned to True for all Logic Item
@@ -1949,35 +2157,35 @@ class FiltersEditorWidget(plugin.PluginWidget):
             if index:
                 self.model.add_condition_item(parent=index, value=cond)
 
-    def on_delete_item(self):
-        """Delete current item
+    # def on_delete_item(self):
+    #     """Delete current item
 
-        - if filter is saved => delete filter
-        - if filter is not saved => clear
-        """
-        ret = QMessageBox.question(
-            self,
-            self.tr("Filter deletion"),
-            self.tr("Do you want to remove this filter?"),
-            QMessageBox.Yes | QMessageBox.No,
-        )
+    #     - if filter is saved => delete filter
+    #     - if filter is not saved => clear
+    #     """
+    #     ret = QMessageBox.question(
+    #         self,
+    #         self.tr("Filter deletion"),
+    #         self.tr("Do you want to remove this filter?"),
+    #         QMessageBox.Yes | QMessageBox.No,
+    #     )
 
-        if ret == QMessageBox.Yes:
-            current_index = self.combo.currentIndex()
-            if current_index == 0:
-                # Not saved filter
-                self.model.clear()
-            else:
-                # Saved filter
-                # Delete from app settings
-                self.settings.beginGroup("plugins/filters_editor/filters")
-                self.settings.remove(self.combo.currentText())
-                self.settings.endGroup()
+    #     if ret == QMessageBox.Yes:
+    #         current_index = self.combo.currentIndex()
+    #         if current_index == 0:
+    #             # Not saved filter
+    #             self.model.clear()
+    #         else:
+    #             # Saved filter
+    #             # Delete from app settings
+    #             self.settings.beginGroup("plugins/filters_editor/filters")
+    #             self.settings.remove(self.combo.currentText())
+    #             self.settings.endGroup()
 
-                # Delete from combobox
-                self.combo.removeItem(current_index)
+    #             # Delete from combobox
+    #             self.combo.removeItem(current_index)
 
-            self.refresh_buttons()
+    #         self.refresh_buttons()
 
     def on_selection_changed(self):
         """Enable/Disable add button depending item type
@@ -1987,20 +2195,20 @@ class FiltersEditorWidget(plugin.PluginWidget):
         """
         self.refresh_buttons()
 
-    def contextMenuEvent(self, event: QContextMenuEvent):
+    # def contextMenuEvent(self, event: QContextMenuEvent):
 
-        pos = self.view.viewport().mapFromGlobal(event.globalPos())
-        index = self.view.indexAt(pos)
+    #     pos = self.view.viewport().mapFromGlobal(event.globalPos())
+    #     index = self.view.indexAt(pos)
 
-        if index.isValid():
-            menu = QMenu(self)
+    #     if index.isValid():
+    #         menu = QMenu(self)
 
-            item = self.model.item(index)
-            if item.type == FilterItem.LOGIC_TYPE:
-                menu.addAction(self.tr("Add condition"), self.on_add_condition)
-                menu.addAction(self.tr("Add subfilter"), self.on_add_logic)
+    #         item = self.model.item(index)
+    #         if item.type == FilterItem.LOGIC_TYPE:
+    #             menu.addAction(self.tr("Add condition"), self.on_add_condition)
+    #             menu.addAction(self.tr("Add subfilter"), self.on_add_logic)
 
-            menu.exec_(event.globalPos())
+    #         menu.exec_(event.globalPos())
 
 
 if __name__ == "__main__":
@@ -2015,12 +2223,6 @@ if __name__ == "__main__":
     import cutevariant.commons as cm
     from cutevariant.gui.ficon import FIcon, setFontPath
 
-    conn = get_sql_connection("test.db")
-
-    d = FieldDialog(conn)
-    d.show()
-    # ---
-
     setFontPath(cm.FONT_FILE)
 
     conn = sql.get_sql_connection(":memory:")
@@ -2034,6 +2236,34 @@ if __name__ == "__main__":
             {"field": "gene", "operator": "=", "value": "chr12"},
             {"field": "gene", "operator": "=", "value": "chr12"},
             {"field": "gene", "operator": "=", "value": "chr12"},
+            {
+                "AND": [
+                    {"field": "gene", "operator": "=", "value": "chr12"},
+                    {"field": "gene", "operator": "=", "value": "chr12"},
+                    {
+                        "AND": [
+                            {"field": "gene", "operator": "=", "value": "chr12"},
+                            {"field": "gene", "operator": "=", "value": "chr12"},
+                            {
+                                "AND": [
+                                    {
+                                        "field": "gene",
+                                        "operator": "=",
+                                        "value": "chr12",
+                                    },
+                                    {
+                                        "field": "gene",
+                                        "operator": "=",
+                                        "value": "chr12",
+                                    },
+                                ]
+                            },
+                        ]
+                    },
+                ]
+            },
+            {"field": "gene", "operator": "=", "value": "chr12"},
+            {"field": "gene", "operator": "=", "value": "chr12"},
         ]
     }
 
