@@ -14,7 +14,7 @@ class State:
     def __init__(self):
 
         # query
-        self.fields = ["favorite", "chr", "pos", "ref", "alt"]
+        self.fields = ["favorite", "classification", "chr", "pos", "ref", "alt", "qual"]
         self.source = "variants"
         self.filters = {}
         self.group_by = []
