@@ -2,21 +2,37 @@
 from cutevariant.commons import DIR_STYLES
 from PySide2.QtGui import QPalette, QColor
 
-TYPE_COLORS = {
-    "str": "#27A4DD",  # blue
-    "bool": "#F1646C",  # red
-    "float": "#9DD5C0",  # light blue
-    "int": "#FAC174",  # light yellow
-    "NoneType": "#FFFFFF",  # white
+
+CLASSIFICATION = {
+    0: {"name": "Unclassified", "icon": 0xF03A1, "color": "lightgray"},
+    1: {"name": "Benin", "icon": 0xF03A4, "color": "#71e096"},
+    2: {"name": "Likely benin", "icon": 0xF03A7, "color": "#71e096"},
+    3: {
+        "name": "Variant of uncertain significance",
+        "icon": 0xF03AA,
+        "color": "#f5a26f",
+    },
+    4: {"name": "Likely pathogen", "icon": 0xF03AD, "color": "#ed6d79"},
+    5: {"name": "Pathogen", "icon": 0xF03B1, "color": "#ed6d79"},
 }
 
-IMPACT_COLOR = {
-    "LOW": "#71E096",
-    "MODERATE": "#F5A26F",
-    "HIGH": "#ed6d79",
-    "MODIFIER": "#55abe1",
+
+GENOTYPE = {
+    -1: {"name": "Unknown genotype", "icon": 0xF10D3},
+    0: {"name": "Homozygous wild", "icon": 0xF0766},
+    1: {"name": "Heterozygous", "icon": 0xF0AA1},
+    2: {"name": "Homozygous muted", "icon": 0xF0AA5},
 }
 
+
+FIELD_TYPE = {
+    "float": {"name": "floating ", "icon": 0xF03A0, "color": "#71e096"},
+    "int": {"name": "integer", "icon": 0xF03A0, "color": "#f5a26f"},
+    "str": {"name": "text", "icon": 0xF100D, "color": "#ed6d79"},
+    "bool": {"name": "boolean", "icon": 0xF023B, "color": "#949cdf"},
+}
+
+
 GENE_COLOR = "#F5A26F"
 WARNING_BACKGROUND_COLOR = "#FFCCBA"
 WARNING_TEXT_COLOR = "#D73705"
